@@ -1,6 +1,6 @@
 import dbus
 import logging
-from dbus.mainloop.glib import DBusGMainLoop
+from dbus.mainloop.glib import DBusGMainLoop, threads_init
 from usbcreator.backends.base import Backend
 from usbcreator import misc
 
@@ -19,6 +19,7 @@ class UDisksBackend(Backend):
         self.allow_system_internal = allow_system_internal
         logging.debug('UDisksBackend')
         DBusGMainLoop(set_as_default=True)
+        threads_init()
         if bus:
             self.bus = bus
         else:
